@@ -56,6 +56,7 @@ class SQLServerDataSource(DataSource):
     ]
 
     TEXT_TYPES_FOR_PROFILING = ["char", "varchar", "text"]
+    LIMIT_KEYWORD = "TOP"
 
     def __init__(self, logs: Logs, data_source_name: str, data_source_properties: dict):
         super().__init__(logs, data_source_name, data_source_properties)
@@ -71,7 +72,11 @@ class SQLServerDataSource(DataSource):
         self.encrypt = data_source_properties.get("encrypt", False)
         self.trust_server_certificate = data_source_properties.get("trust_server_certificate", False)
 
-        self.DEFAULT_FORMAT_EXPRESSIONS.update(self.build_default_format_expressions())
+        # sqlserver reuses only a handful of default formats.
+        reuse_formats = ["percentage"]
+
+        self.DEFAULT_FORMATS = {k: v for k, v in self.DEFAULT_FORMATS.items() if k in reuse_formats}
+        self.DEFAULT_FORMAT_EXPRESSIONS = self.build_default_format_expressions()
 
     def build_default_format_expressions(self) -> dict[str, str]:
         def construct_like(
@@ -286,30 +291,55 @@ class SQLServerDataSource(DataSource):
         return sql
 
     def sql_select_column_with_filter_and_limit(
-        self, column_name: str, table_name: str, filter_clause: str, limit: int | None = None
+        self,
+        column_name: str,
+        table_name: str,
+        filter_clause: str | None = None,
+        sample_clause: str | None = None,
+        limit: int | None = None,
     ) -> str:
+        """
+        Returns a SQL query that selects a column from a table with optional filter, sample query
+        and limit.
+        """
+        filter_clauses_str = f"\n WHERE {filter_clause}" if filter_clause else ""
+        sample_clauses_str = f"\n {sample_clause}" if sample_clause else ""
+        limit_clauses_str = f"TOP {limit}" if limit else ""
 
-        sql = f"SELECT TOP {limit} \n" f" {column_name} \n" f"FROM {table_name}{filter_clause}"
+        sql = (
+            f"SELECT {limit_clauses_str} \n"
+            f"  {column_name} \n"
+            f"FROM {table_name}{sample_clauses_str}{filter_clauses_str}"
+        )
         return sql
 
     def expr_false_condition(self):
         return "1 = 0"
 
     def sql_get_duplicates(
-        self, column_names: str, table_name: str, filter: str, limit: str | None = None
+        self,
+        column_names: str,
+        table_name: str,
+        filter: str,
+        limit: str | None = None,
+        invert_condition: bool = False,
     ) -> str | None:
         limit_sql = ""
 
         if limit:
-            limit_sql = f" TOP {limit} "
+            limit_sql = f"TOP {limit}"
 
-        sql = f"""WITH frequencies AS (
+        sql = dedent(
+            f"""
+            WITH frequencies AS (
               SELECT {column_names}, COUNT(*) AS frequency
               FROM {table_name}
               WHERE {filter}
               GROUP BY {column_names})
             SELECT {limit_sql} {column_names}, frequency
             FROM frequencies
-            WHERE frequency > 1"""
+            WHERE frequency {'<=' if invert_condition else '>'} 1
+            ORDER BY frequency DESC"""
+        )
 
         return sql
